#
# spec file for package enet
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 7
Name:           enet
Version:        1.3.17
Release:        bp154.1.58
Summary:        Network Communication Layer on Top of UDP
License:        MIT
Group:          Productivity/Networking/Other
URL:            http://enet.bespin.org/
Source:         http://enet.bespin.org/download/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig

%description
ENet provides a relatively thin network communication layer on top of
UDP (User Datagram Protocol). The primary feature it provides is
optional reliable, in-order delivery of packets.

ENet omits certain higher level networking features such as authentication,
lobbying, server discovery, encryption, or other similar tasks that are
particularly application specific so that the library remains flexible,
portable, and embeddable.

%package -n libenet%{sover}
Summary:        Library files for libenet
Group:          System/Libraries

%description -n libenet%{sover}
The libenet7 package contains libraries for libenet.

%package devel
Summary:        Development files for libenet
Group:          Development/Libraries/C and C++
Requires:       libenet%{sover} = %{version}

%description devel
The libenet-devel package contains libraries and header files for
developing applications that use libenet.

%prep
%setup -q

%build
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print

# Correct what fdupes didn't find, because docs are later installed
rm -f docs/html/ftv2link.png
ln -sf ../../docs/html/ftv2doc.png docs/html/ftv2link.png
rm -f docs/html/ftv2mnode.png
ln -sf ../../docs/html/ftv2mlastnode.png docs/html/ftv2mnode.png
rm -f docs/html/{ftv2blank,ftv2vertline,ftv2lastnode}.png
ln -sf ../../docs/html/ftv2node.png docs/html/ftv2blank.png
ln -sf ../../docs/html/ftv2node.png docs/html/ftv2vertline.png
ln -sf ../../docs/html/ftv2node.png docs/html/ftv2lastnode.png
rm -f docs/html/ftv2plastnode.png
ln -sf ../../docs/html/ftv2pnode.png docs/html/ftv2plastnode.png
rm -f docs/html/search/variables_1.js
ln -sf ../../docs/html/search/all_1.js docs/html/search/variables_1.js
rm -f docs/html/search/variables_11.js
ln -sf ../../docs/html/search/all_11.js docs/html/search/variables_11.js
rm -f docs/html/search/variables_a.js
ln -sf ../../docs/html/search/all_a.js docs/html/search/variables_a.js
rm -f docs/html/search/variables_0.js
ln -sf ../../docs/html/search/all_0.js docs/html/search/variables_0.js
rm -f docs/html/search/variables_b.js
ln -sf ../../docs/html/search/all_b.js docs/html/search/variables_b.js
rm -f docs/html/search/variables_d.js
ln -sf ../../docs/html/search/all_d.js docs/html/search/variables_d.js

%post -n libenet%{sover} -p /sbin/ldconfig
%postun -n libenet%{sover} -p /sbin/ldconfig

%files -n libenet%{sover}
%{_libdir}/libenet.so.%{sover}*

%files devel
%license LICENSE
%doc ChangeLog README docs/html
%{_includedir}/enet
%{_libdir}/libenet.so
%{_libdir}/pkgconfig/libenet.pc

%changelog
* Sun Dec 20 2020 Dirk Müller <dmueller@suse.com>
- update to 1.3.17:
  * fixes for sender getting too far ahead or receiver that can cause instability with reliable packets
* Thu Sep 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.3.16:
  * fix bug in unreliable fragment queuing
  * use single output queue for reliable and unreliable packets for saner ordering
  * revert experimental throttle changes that were less stable than prior algorithm
* Thu Apr 23 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.3.15
  * quicker RTT initialization
  * use fractional precision for RTT calculations
  * fixes for packet throttle with low RTT variance
  * miscellaneous socket bug fixes
* Thu Mar 14 2019 Jan Engelhardt <jengelh@inai.de>
- Rename %%soname to %%sover to better match its use.
- Remove unnecessary extra pkgconfig require that is already
  implicit.
- Trim bias from descriptions.
* Mon Mar 11 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.3.14
  * bug fix for enet_peer_disconnect_later()
  * use getaddrinfo and getnameinfo where available
  * miscellenous cleanups
- Run spec-cleaner
* Tue May 19 2015 nemysis@gmx.ch
- Update to 1.3.13, announce message:
  * miscellaneous bug fixes
  * added premake and cmake support
  * miscellaneous documentation cleanups
- Adjust what fdupes not have found
* Sun Dec  7 2014 nemysis@gmx.ch
- Update to 1.3.12
- Correct what fdupes not have found
- Move Documentation to libenet-devel package and add html
* Sun Sep 23 2012 nmo.marques@gmail.com
- Update to version 1.3.5:
  + fixed a big in unreliable packaget fragment queuing
  + Soname bump to 2
- Changes from version 1.3.4:
  + added enet_peer_ping_interval() for configuring per-peer ping
    intervals
  + added enet_peer_timeout() for configuring per-peer timeouts
  + added protocol packet size limits
* Sun Feb 19 2012 jengelh@medozas.de
- Update license field to reflect actual license
* Mon Oct 10 2011 nmarques@opensuse.org
- Update to version 1.3.3:
  + fixed bug with simultaneous disconnects not dispatching events
- Previous versions:
  + added support for unreliable packet fragmenting via the packet
    flag ENET_PACKET_FLAG_UNRELIABLE_FRAGMENT
  + fixed regression in unreliable packet queuing
  + added check against received port to limit some forms of
    IP-spoofing
* Mon May  9 2011 nmarques@opensuse.org
- Update to version 1.3.1:
  + fixed bug in tracking of reliable data in transit;
  + reliable data window size now scales with the throttle;
  + fixed bug in fragment length calculation when checksums are
    used;
- Spec changes:
  + Added pkg-config to Requirements of devel pack (provides .pc);
  + Added changes to enable Fedora builds on spec;
  + Added %%doc macros to files;
  + Added spec file openSUSE headers;
  + Removed %%check macro;
  + Minor tweaks.
- Moved file 'libenet.spec.changes' to 'libenet.changes'.
* Mon Jul 12 2010 bitshuffler@opensuse.org
- Initial package
